<?php
/*
Plugin Name: FontSizeSelect
Version: 1.4
Plugin URI: https://nhws.localinfo.jp/
Description: Visitors can select the default FontSize.
Author: ぴー＠西東京
Author URI: https://nhws.localinfo.jp/
*/ 


register_widget('fontsizeselect', 'FontSizeSelect', 'plugin_fontsizeselect_widget');
add_action('wp_head', 'plugin_fontsizeselect_head');
add_action('wp_footer', 'plugin_fontsizeselect_footer');


function plugin_fontsizeselect_widget() {
	
	$fontsizeselectconf = plugin_getoptions('fontsizeselect');	//設定の読み出し
	$lang = lang_load('plugin:fontsizeselect');	// 多言語対応
	
	$fontsizeselectconf['sizes'] = isset($fontsizeselectconf['sizes']) ? $fontsizeselectconf['sizes'] : "1";
	$fontsizeselectconf['sizem'] = isset($fontsizeselectconf['sizem']) ? $fontsizeselectconf['sizem'] : "1.16";
	$fontsizeselectconf['sizel'] = isset($fontsizeselectconf['sizel']) ? $fontsizeselectconf['sizel'] : "1.33";
	$fontsizeselectconf['expire'] = isset($fontsizeselectconf['expire']) ? $fontsizeselectconf['expire'] : "5";
	
	if($fontsizeselectconf['display'] == '1') $title = $lang['plugin']['fontsizeselect']['title'];
	
	$content = "<div class=\"fontsizeselect\">
	<span>{$title}</span>
	<a href=\"#\" onclick=\"tglBtn('{$fontsizeselectconf['sizes']}em',{$fontsizeselectconf['expire']});bgChg(this);\">&nbsp;{$lang['plugin']['fontsizeselect']['small']}&nbsp;</a><a href=\"#\" onclick=\"tglBtn('{$fontsizeselectconf['sizem']}em',{$fontsizeselectconf['expire']});bgChg(this);\">&nbsp;{$lang['plugin']['fontsizeselect']['middle']}&nbsp;</a><a href=\"#\" onclick=\"tglBtn('{$fontsizeselectconf['sizel']}em',{$fontsizeselectconf['expire']});bgChg(this);\">&nbsp;{$lang['plugin']['fontsizeselect']['large']}&nbsp;</a>
	</div>";
	
	return array(
		'subject' => 'FontSizeSelect',
		'content' => $content
	);
}


function plugin_fontsizeselect_head() {
	
	$fontsizeselectconf = plugin_getoptions('fontsizeselect');	//設定の読み出し
	$pdir = plugin_geturl('fontsizeselect');
	$fontsizeselectconf['type'] = isset($fontsizeselectconf['type']) ? $fontsizeselectconf['type'] : "1";
	
	echo <<<FONTSIZESELECTHEAD
\n	<!-- start of fontsizeselect -->
	<link rel="stylesheet" type="text/css" href="{$pdir}res/fontsizeselect{$fontsizeselectconf['type']}.css" />
	<script src="https://cdn.jsdelivr.net/npm/js-cookie@2/src/js.cookie.min.js"></script>
	<script type="text/javascript" src="{$pdir}res/fontsizeselect.js"></script>
	<!-- end of fontsizeselect -->\n
FONTSIZESELECTHEAD;
}


function plugin_fontsizeselect_footer() {
	
	$fontsizeselectconf = plugin_getoptions('fontsizeselect');	//設定の読み出し
//	$pdir = plugin_geturl('fontsizeselect');
	
	echo <<<FONTSIZESELECTFOOT
\n	<!-- start of fontsizeselect -->
	<script type="text/javascript">
	var cols = document.querySelectorAll('.fontsizeselect a');
	var setSize = Cookies.get('fpFontSizeSelect');
	if( !setSize ) setSize = '{$fontsizeselectconf['sizes']}em';
	tglBtn(setSize,{$fontsizeselectconf['expire']});
	if( setSize == '{$fontsizeselectconf['sizes']}em' )	cols[0].classList.add('selected');
	if( setSize == '{$fontsizeselectconf['sizem']}em' )	cols[1].classList.add('selected');
	if( setSize == '{$fontsizeselectconf['sizel']}em' )	cols[2].classList.add('selected');
	</script>
	<!-- end of fontsizeselect -->\n
FONTSIZESELECTFOOT;
}


if (class_exists('AdminPanelAction')){
	/*
	Provides an admin panel entry for FontSizeSelect setup.
	*/
	class admin_plugin_fontsizeselect extends AdminPanelAction { 
		var $langres = 'plugin:fontsizeselect';
		
		/*
		Initializes this panel.
		*/
		function setup() {
			$this->smarty->assign('admin_resource', "plugin:fontsizeselect/admin.plugin.fontsizeselect");
		}
		
		/*
		Setups the default panel.
		*/
		function main() {
			$fontsizeselectconf = plugin_getoptions('fontsizeselect');	//設定の読み出し
			
			$fontsizeselectconf['sizes'] = isset($fontsizeselectconf['sizes']) ? $fontsizeselectconf['sizes'] : "1";
			$fontsizeselectconf['sizem'] = isset($fontsizeselectconf['sizem']) ? $fontsizeselectconf['sizem'] : "1.16";
			$fontsizeselectconf['sizel'] = isset($fontsizeselectconf['sizel']) ? $fontsizeselectconf['sizel'] : "1.33";
			$fontsizeselectconf['expire'] = isset($fontsizeselectconf['expire']) ? $fontsizeselectconf['expire'] : "5";
			$fontsizeselectconf['type'] = isset($fontsizeselectconf['type']) ? $fontsizeselectconf['type'] : "1";
			
			$this->smarty->assign('fontsizeselectconf', $fontsizeselectconf);
		}
		
		/*
		Will be executed when the FontSizeSelect configuscorethresholdn is send.
		
		@return int
		*/
		function onsubmit() {
			global $fp_config;
			if ($_POST['sizel'] && $_POST['sizem'] && $_POST['sizes'] && $_POST['expire'] && $_POST['type']){
				if (!(2 >= $_POST['sizel'] && $_POST['sizel'] > $_POST['sizem'] && $_POST['sizem'] > $_POST['sizes'] && $_POST['sizes'] >= 0.5)){
					$_POST['sizes'] = 1;
					$_POST['sizem'] = 1.16;
					$_POST['sizel'] = 1.33;
				}
				plugin_addoption('fontsizeselect', 'sizes', $_POST['sizes']);
				plugin_addoption('fontsizeselect', 'sizem', $_POST['sizem']);
				plugin_addoption('fontsizeselect', 'sizel', $_POST['sizel']);
				plugin_addoption('fontsizeselect', 'expire', $_POST['expire']);
				plugin_addoption('fontsizeselect', 'type', $_POST['type']);
				plugin_addoption('fontsizeselect', 'display', $_POST['display']);
				plugin_saveoptions('fontsizeselect');
				
				$this->smarty->assign('success', 1);
			} else {
				$this->smarty->assign('success', -1);
			}
			return 2;
		}		
	}
	admin_addpanelaction('plugin', 'fontsizeselect', true);
}


?>
